Interpreter

Struct Interpreter 

pub struct Interpreter { /* private fields */ }
A Brainfuck interpreter that supports breakpoints.

Implementations

Source

impl Interpreter

pub fn new(code: Vec<BrainfuckInstruction>) -> Self

Creates a new Interpreter form some input program.

Arguments
  • code - A sequence of BrainfuckInstructions to be interpreted.
pub fn set_breakpoint(&mut self, address: usize) -> Result<bool, String>

Sets a breakpoint at the specified code address.

Arguments
  • address - The code address to set a breakpoint at.
pub fn delete_breakpoint(&mut self, address: usize) -> bool

Removes a breakpoint at the specified code address.

Arguments
  • address - The code address to delete a breakpoint from.
pub fn run(&mut self) -> StopReason

Runs the Interpreter until either a breakpoint is hit or until the program has run to completion.

pub fn step(&mut self)

Executes a single BrainfuckInstruction.

pub fn get(&self, address: usize) -> Result<u8, String>

Reads a value from the tape at the specified address.

Arguments
  • address - The tape address to read.
pub fn set(&mut self, address: usize, value: u8) -> Result<u8, String>

Writes a value to the tape at the specified address.

Arguments
  • address - The tape address to write to.
  • value - The value to write.
pub fn jump(&mut self, address: usize) -> Result<(), String>

Sets the instruction pointer to the specified code address.

Arguments
  • address - The code address to jump to.
pub fn select(&mut self, address: usize) -> Result<(), String>

Sets the data pointer to the specified tape address.

Arguments
  • address - The tape address to set the data pointer to.